@@ -1,5 +1,5 @@
 package GeoIP2::Error::Generic;
-$GeoIP2::Error::Generic::VERSION = '0.040005';
+$GeoIP2::Error::Generic::VERSION = '0.050000';
 use strict;
 use warnings;
 
@@ -21,7 +21,7 @@ GeoIP2::Error::Generic - A generic exception
 
 =head1 VERSION
 
-version 0.040005
+version 0.050000
 
 =head1 SYNOPSIS
 
@@ -37,7 +37,7 @@ version 0.040005
   );
 
   try {
-      $client->omni( ip => '24.24.24.24' );
+      $client->insights( ip => '24.24.24.24' );
   }
   catch {
       die $_ unless blessed $_;
