@@ -1,5 +1,5 @@
 package GeoIP2::Error::IPAddressNotFound;
-$GeoIP2::Error::IPAddressNotFound::VERSION = '0.040005';
+$GeoIP2::Error::IPAddressNotFound::VERSION = '0.050000';
 use strict;
 use warnings;
 
@@ -29,7 +29,7 @@ GeoIP2::Error::IPAddressNotFound - An exception thrown when an IP address is not
 
 =head1 VERSION
 
-version 0.040005
+version 0.050000
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,7 @@ version 0.040005
   );
 
   try {
-      $client->omni( ip => '24.24.24.24' );
+      $client->insights( ip => '24.24.24.24' );
   }
   catch {
       die $_ unless blessed $_;
