@@ -1,5 +1,5 @@
 package GeoIP2::Error::WebService;
-$GeoIP2::Error::WebService::VERSION = '0.040005';
+$GeoIP2::Error::WebService::VERSION = '0.050000';
 use strict;
 use warnings;
 
@@ -31,7 +31,7 @@ GeoIP2::Error::WebService - An explicit error from the GeoIP2 web service
 
 =head1 VERSION
 
-version 0.040005
+version 0.050000
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ version 0.040005
   );
 
   try {
-      $client->omni( ip => '24.24.24.24' );
+      $client->insights( ip => '24.24.24.24' );
   }
   catch {
       die $_ unless blessed $_;
