@@ -1,5 +1,5 @@
 package GeoIP2::Record::Traits;
-$GeoIP2::Record::Traits::VERSION = '0.040005';
+$GeoIP2::Record::Traits::VERSION = '0.050000';
 use strict;
 use warnings;
 
@@ -74,7 +74,7 @@ GeoIP2::Record::Traits - Contains data for the traits record associated with an
 
 =head1 VERSION
 
-version 0.040005
+version 0.050000
 
 =head1 SYNOPSIS
 
@@ -87,9 +87,9 @@ version 0.040005
       license_key => 'abcdef123456',
   );
 
-  my $omni = $client->omni( ip => '24.24.24.24' );
+  my $insights = $client->insights( ip => '24.24.24.24' );
 
-  my $traits_rec = $omni->country();
+  my $traits_rec = $insights->country();
   say $traits_rec->name();
 
 =head1 DESCRIPTION
